local addonName = ...
local addonTitle = select(2, GetAddOnInfo(addonName))
local db, dbpc

HideRetail = LibStub("AceAddon-3.0"):NewAddon(addonName, "AceConsole-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("HideRetail", "enUS")

local options = { -- OptionsTable
    name =  L['Hide Retail'],
	type = 'group',
    args = {
		intro = {
			get = function(info) return dbpc.enabledoptions[ info[#info] ] end,
			set = function(info, value) dbpc.enabledoptions[ info[#info] ] = value UpdateALL() end,
			order = 1,
			guiInline = true,
			type = "group",
			name = L["These settings are character specific."],
			args = {
				ALL = {
					type = 'toggle',
					name = L['Hide ALL'],
				},
			},
		},
		InterfaceOptions = {
			get = function(info) return dbpc.enabledoptions[ info[#info] ] end,
			set = function(info, value) dbpc.enabledoptions[ info[#info] ] = value UpdateMicroButtons() end,
			type = "group",
			order = 2,
			guiInline = true,
			name = L["Interface Options"],
			args = {
				Achievement = {
					type = 'toggle',
					name = L['Hide Achievement - Removes KeyBinds'],
					width = 'full',
				},
				AdventureGuide = {
					type = 'toggle',
					name = L['Hide AdventureGuide - Removes KeyBinds'],
					width = 'full',
				},
				LFD = {
					type = 'toggle',
					name = L['Hide LFDungeon - Removes KeyBinds'],
					width = 'full',
				},
				Shop = {
					type = 'toggle',
					name = L['Hide Shop'],
					width = 'full',
				},
			},
		},
		Other = {
			get = function(info) return dbpc.enabledoptions[ info[#info] ] end,
			set = function(info, value) dbpc.enabledoptions[ info[#info] ] = value end,
			type = "group",
			order = 2,
			guiInline = true,
			name = L["Other Interface Options - Requires RELOAD"],
			args = {
				Gryphons = {
					type = 'toggle',
					order = 1,
					name = L['Hide Gryphons'],
				},
				Alerts = {
					type = 'toggle',
					order = 2,
					name = L['Hide MicroBar Alerts'],
				},
				Errors = {
					type = 'toggle',
					order = 3,
					name = L['Hide Errors Frame'],
				},
				LoadingTips = {
					type = 'toggle',
					order = 4,
					name = L['Hide LoadingScreenTips'],
				},
				PvPTalents = {
					type = 'toggle',
					order = 5,
					name = L['Hide PvP Talents'],
				},
				StanceBar = {
					type = 'toggle',
					order = 6,
					name = L['Hide StanceBar'],
					disabled = function () if (GetNumShapeshiftForms() ~= 0) == true then return false else return true end end,
				},
			},
		},
		Collections = {
			get = function(info) return dbpc.enabledoptions[ info[#info] ] end,
			set = function(info, value) dbpc.enabledoptions[ info[#info] ] = value end,
			type = "group",
			order = 3,
			guiInline = true,
			name = L["Collections Interface - Requires RELOAD"],
			args = {
				Heirlooms = {
					type = 'toggle',
					name = L['Hide Heirlooms - Removes KeyBinds'],
					width = 'full',
				},
				Appearances = {
					type = 'toggle',
					name = L['Hide Appearances - Removes KeyBinds'],
					width = 'full',
				},
				cleardata = {
					type = "execute",
					name = L["RELOAD UI"], -- Query Options
					func = function() ReloadUI() end,
				},
			},
		},
    },
}

------------------ Option Menu Interface
local acr = LibStub("AceConfigRegistry-3.0")
local acd = LibStub("AceConfigDialog-3.0")

function HideRetail:OnInitialize()
	--RegisterDB
    self.db = LibStub("AceDB-3.0"):New("HRDB", {
			profile = {
			},
		}, "global")
	db = self.db.profile
	self.dbpc = LibStub("AceDB-3.0"):New("HRDBPC", {
			profile = {
				enabledoptions = {
					ALL = false,
					-- MicroBar
					Achievement = false, -- Removes KeyBinds
					AdventureGuide = false, -- Removes KeyBinds
					LFD = false, -- Removes KeyBinds
					Shop = false,
					-- Other
					Gryphons = true,
					Alerts = true,
					Errors = true,
					LoadingTips = LoadingScreenTips(),
					PvPTalents = false,
					StanceBar = false,
					-- Collections Interface
					Appearances = false, -- Removes KeyBinds
					Heirlooms = false, -- Removes KeyBinds
				},
		    },
		}, "global")
	dbpc = self.dbpc.profile
	acr:RegisterOptionsTable(addonName, options)	-- RegisterOptionsTable
	local options = acd:AddToBlizOptions(addonName, L["Hide Retail"]) -- Adds Options to Interface/Addon
end

function UpdateALL()
	if dbpc.enabledoptions.ALL then
		dbpc.enabledoptions.Achievement = true
		dbpc.enabledoptions.AdventureGuide = true
		dbpc.enabledoptions.LFD = true
		dbpc.enabledoptions.Shop = true
		
		dbpc.enabledoptions.Gryphons = true
		dbpc.enabledoptions.Alerts = true
		dbpc.enabledoptions.Errors = true
		dbpc.enabledoptions.LoadingTips = true
		dbpc.enabledoptions.PvPTalents = true
		if (GetNumShapeshiftForms() ~= 0) == true then
			dbpc.enabledoptions.StanceBar = true
		end

		dbpc.enabledoptions.Appearances = true
		dbpc.enabledoptions.Heirlooms = true
	else
		dbpc.enabledoptions.Achievement = false
		dbpc.enabledoptions.AdventureGuide = false
		dbpc.enabledoptions.LFD = false
		dbpc.enabledoptions.Shop = false
		
		dbpc.enabledoptions.Gryphons = false
		dbpc.enabledoptions.Alerts = false
		dbpc.enabledoptions.Errors = false
		dbpc.enabledoptions.LoadingTips = false
		dbpc.enabledoptions.PvPTalents = false
		if (GetNumShapeshiftForms() ~= 0) == true then
			dbpc.enabledoptions.StanceBar = false
		end

		dbpc.enabledoptions.Appearances = false
		dbpc.enabledoptions.Heirlooms = false
	end
end
 -- Hooks into the UpdateMicroButtons
hooksecurefunc("UpdateMicroButtons",function(...)
	if dbpc.enabledoptions.Achievement then
		AchievementMicroButton:Hide() else AchievementMicroButton:Show() end
	if dbpc.enabledoptions.Shop then
		StoreMicroButton:Hide() else StoreMicroButton:Show() end
	if dbpc.enabledoptions.AdventureGuide then
		EJMicroButton:Hide() else EJMicroButton:Show() end
	if dbpc.enabledoptions.LFD then
		LFDMicroButton:Hide() else LFDMicroButton:Show() end
end)
-- Checks LoadingScreenTips setting
function LoadingScreenTips()
	if GetCVar("showLoadingScreenTips") == "0" then return true
	else return false
	end
end
-- Remove KeyBinds
function UnBind(key)
	SetBinding(key)
	SaveBindings(GetCurrentBindingSet()) -- Otherwise they will reset
end
-- Chat Filter
function filterAchievement(msg)
	return true
end
 -- Collections Interface
local HideRetail = CreateFrame("Frame")
HideRetail:RegisterEvent("ADDON_LOADED") -- Collections
HideRetail:RegisterEvent("PLAYER_LOGIN")
-- Triggers on Alert?
function MainMenuMicroButton_AreAlertsEnabled()
	if dbpc.enabledoptions.Alerts then
		return false
	end
end
HideRetail:SetScript("OnEvent", function(self, event, ...)
-- Hides Collections
	if IsAddOnLoaded("Blizzard_Collections") then
		if dbpc.enabledoptions.Heirlooms then
			CollectionsJournalTab4:Hide()
		else CollectionsJournalTab4:Show() end
		if dbpc.enabledoptions.Appearances then
			CollectionsJournalTab5:Hide()
		else CollectionsJournalTab5:Show() end
-- Hides PvP Talents
	elseif IsAddOnLoaded("Blizzard_TalentUI") then
		hooksecurefunc("PlayerTalentFrame_Update",function(...)
			local selectedTab = PanelTemplates_GetSelectedTab(PlayerTalentFrame)
			if selectedTab == 2 then
				if dbpc.enabledoptions.PvPTalents then
					PlayerTalentFrameTalentsPvpTalentButton:Hide()
					PlayerTalentFrame_SetExpanded(false)
				-- Below level 20 shows but doesn't work
				elseif (PlayerTalentFrameTalentsPvpTalentButton:IsShown() == false) then
					PlayerTalentFrameTalentsPvpTalentButton:Show()
				end
			end
		end)
	end
---- Other Interface Options
    if event == "PLAYER_LOGIN" then
		HideRetail:UnregisterEvent("PLAYER_LOGIN")
-- LoadingScreenTips
		if dbpc.enabledoptions.LoadingTips then -- if enabled
			if LoadingScreenTips() == false then -- and tooltips ON
				SetCVar("showLoadingScreenTips", 0) -- turn tooltips OFF
			end
		elseif LoadingScreenTips() then -- if tooltips OFF
			SetCVar("showLoadingScreenTips", 1) -- turn tooltips ON
		end
-- Gryphons
		if dbpc.enabledoptions.Gryphons then
			MainMenuBarArtFrame.LeftEndCap:Hide() MainMenuBarArtFrame.RightEndCap:Hide()
		else
			MainMenuBarArtFrame.LeftEndCap:Show() MainMenuBarArtFrame.RightEndCap:Show()
		end
-- StanceBar
		if dbpc.enabledoptions.StanceBar then RegisterStateDriver(StanceBarFrame, "visibility", "hide") end
-- Error Frame Messages
		if dbpc.enabledoptions.Errors then UIErrorsFrame:UnregisterEvent("UI_ERROR_MESSAGE") end
		local Unbindkeys = {}
-- Achievements
		if dbpc.enabledoptions.Achievement then
			table.insert(Unbindkeys, "TOGGLEACHIEVEMENT")
			table.insert(Unbindkeys, "TOGGLESTATISTICS")
-- Filter Chat Announcements
			ChatFrame_AddMessageEventFilter("CHAT_MSG_GUILD_ACHIEVEMENT", filterAchievement)
			ChatFrame_AddMessageEventFilter("CHAT_MSG_ACHIEVEMENT", filterAchievement)
-- Hide Achievement Toasts
			local AchievementEvents = {"ACHIEVEMENT_EARNED","CRITERIA_EARNED"}
			function HideRetail:Call(func, ...)
				return xpcall(func, errorHandler, ...)
			end
			for _,event in pairs(AchievementEvents) do
				HideRetail:Call(AlertFrame.UnregisterEvent, AlertFrame, event)
			end
		end
-- Heirlooms
		if dbpc.enabledoptions.Heirlooms then
			table.insert(Unbindkeys, "TOGGLECOLLECTIONSHEIRLOOM")
		end
-- Appearances
		if dbpc.enabledoptions.Appearances then
			table.insert(Unbindkeys, "TOGGLECOLLECTIONSWARDROBE")
		end
-- Move Collections Bindkey to Mount
		if dbpc.enabledoptions.Appearances or dbpc.enabledoptions.Heirlooms then
			local key1, key2 = GetBindingKey("TOGGLECOLLECTIONS")
			if key1 ~= nil then
				SetBinding(key1, "TOGGLECOLLECTIONSMOUNTJOURNAL")
			end
			table.insert(Unbindkeys, "TOGGLECOLLECTIONS")
		end
-- Adventure Guide
		if dbpc.enabledoptions.AdventureGuide then
			table.insert(Unbindkeys, "TOGGLEENCOUNTERJOURNAL")
		end
-- LFDungeon
		if dbpc.enabledoptions.LFD then
			table.insert(Unbindkeys, "TOGGLEGROUPFINDER")
			table.insert(Unbindkeys, "TOGGLEDUNGEONSANDRAIDS")
			table.insert(Unbindkeys, "TOGGLECHARACTER4")
		end
-- Unbindkeys
		for _,Unbindkey in pairs(Unbindkeys) do
			local key1, key2 = GetBindingKey(Unbindkey)
			if key1 ~= nil then UnBind(key1) end
			if key2 ~= nil then UnBind(key2) end		
		end
	end
end)